Skip to main content Crate punybuf_common Copy item path Source tokio const_unwrap Bytes A convenience type wrapping a Vec<u8>, for more efficient (de)serialization. Done An empty type, used as a return type for a command that doesn’t need to return
anything, but needs to indicate that it’s been recieved or that the requested
operation finished processing. DuplicateKeysFound UInt A variable-length integer. The greatest supported value is 1152921573328437375. Cow A clone-on-write smart pointer. HashMapConvertible PBCommand A trait that all commands implement. The enum of all commands also implements this trait. PBCommandExt A trait that all individual commands implement. The enum of all commands does not implement this trait. PBType All Punybuf types implement this trait. Void