punybuf_
common
0.1.0
All Items
Crate Items
Modules
Macros
Structs
Traits
Crate
punybuf_common
Modules

tokio
Macros

const_
unwrap
Structs

Bytes
A convenience type wrapping a
Vec<u8>
, for more efficient (de)serialization.
Done
An empty type, used as a return type for a command that doesn’t need to return anything, but needs to indicate that it’s been recieved or that the requested operation finished processing.
Duplicate
Keys
Found
UInt
A variable-length integer. The greatest supported value is 1152921573328437375.
Traits

Hash
MapConvertible
PBCommand
PBType
All Punybuf types implement this trait.